==> ordering-core-0.0.6.tgz: package/lib/esm/orderStore.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { EOrderRecStatus, } from './orderTypes';
let orderRecords = {}; //TODO prune old orders
let orderUpdateCallback;
export const cmdOrderCreate = (ctx, authDataProvider, orderServerTool) => __awaiter(void 0, void 0, void 0, function* () {
    const { id, correlationId } = yield orderServerTool.createOrder(ctx, authDataProvider);
    if (orderRecords[id]) {
        // order already exists, order update or error notification came ealier then REST reponse from create
        // do nothing
    }
    else {
        orderRecords[id] = {
            createOrderCorrelationId: correlationId,
            recStatus: EOrderRecStatus.INITIALIZING,
        };
    }
    if (orderUpdateCallback)
        orderUpdateCallback();
    return { id, correlationId };
});
export const onOrderUpdate = (orderData) => {
    const id = orderData.id;
    if (!id)
        return;
    //console.log('-------- onOrderUpdate ' + id);
    if (!orderRecords[id]) {
        if (orderData.closed)
            return;
        // create new record
        orderRecords[id] = {
            recStatus: EOrderRecStatus.VALID,
            order: toOrder(orderData),
            createOrderCorrelationId: '',
        };
    }
    else {
        // update
        const rec = orderRecords[id];
        if (rec.recStatus === EOrderRecStatus.INITIALIZING) {
            rec.recStatus = EOrderRecStatus.VALID;
        }
        rec.order = toOrder(orderData);
        if (rec.order.closed) {
            //console.log('---------------------- CLOSED:  ' + id);
            delete orderRecords[id];
        }
        //if (rec.recStatus === EOrderRecStatus.INVALID) {
        // ????
        //}
    }
    // console.log(
    //   `Order Store contains ${Object.keys(orderRecords).length} records`,
    // );
    if (orderUpdateCallback)
        orderUpdateCallback();
};
export const onOrderError = (errorMsg) => {
    const id = errorMsg.id;
    if (!id)
        return;
    if (!orderRecords[id]) {
        //error while creating order (there were no order update messages)
        orderRecords[id] = {
            recStatus: EOrderRecStatus.INVALID,
            createOrderCorrelationId: '',
        };
        if (orderUpdateCallback)
            orderUpdateCallback();
    }
    else {
        const rec = orderRecords[id];
        if (rec.createOrderCorrelationId === errorMsg.correlationId) {
            rec.recStatus = EOrderRecStatus.INVALID;
            return;
        }
        if (rec.recStatus === EOrderRecStatus.INITIALIZING) {
            rec.recStatus = EOrderRecStatus.INVALID;
        }
        // notifications or errors for existing (created orders)
        // do nothing
    }
};
export const getOrderStore = () => orderRecords;
export const clearOrderStore = () => {
    orderRecords = {};
};
function toOrder(orderData) {
    const order = {
        id: orderData.id,
        tenant: orderData.tenant,
        orderType: orderData.orderType,
        created: orderData.created,
        status: orderData.status,
        buckets: [],
        closed: orderData.closed,
    };
    return order;
}

==> ordering-core-0.0.7.tgz: package/lib/esm/orderStore.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { EOrderRecStatus, } from './orderTypes';
let orderRecords = {}; //TODO prune old orders
let orderUpdateCallback;
export const setOrderStoreUpdatedCallback = (_callback) => {
    orderUpdateCallback = _callback;
};
export const cmdOrderCreate = (ctx, authDataProvider, orderServerTool) => __awaiter(void 0, void 0, void 0, function* () {
    const { id, correlationId } = yield orderServerTool.createOrder(ctx, authDataProvider);
    if (orderRecords[id]) {
        // order already exists, order update or error notification came ealier then REST reponse from create
        // do nothing
    }
    else {
        orderRecords[id] = {
            createOrderCorrelationId: correlationId,
            recStatus: EOrderRecStatus.INITIALIZING,
        };
    }
    if (orderUpdateCallback)
        orderUpdateCallback(orderRecords);
    return { id, correlationId };
});
export const onOrderUpdate = (orderData) => {
    const id = orderData.id;
    if (!id)
        return;
    //console.log('-------- onOrderUpdate ' + id);
    if (!orderRecords[id]) {
        if (orderData.closed)
            return;
        // create new record
        orderRecords[id] = {
            recStatus: EOrderRecStatus.VALID,
            order: toOrder(orderData),
            createOrderCorrelationId: '',
        };
    }
    else {
        // update
        const rec = orderRecords[id];
        if (rec.recStatus === EOrderRecStatus.INITIALIZING) {
            rec.recStatus = EOrderRecStatus.VALID;
        }
        rec.order = toOrder(orderData);
        if (rec.order.closed) {
            //console.log('---------------------- CLOSED:  ' + id);
            delete orderRecords[id];
        }
        //if (rec.recStatus === EOrderRecStatus.INVALID) {
        // ????
        //}
    }
    // console.log(
    //   `Order Store contains ${Object.keys(orderRecords).length} records`,
    // );
    if (orderUpdateCallback)
        orderUpdateCallback(orderRecords);
};
export const onOrderError = (errorMsg) => {
    const id = errorMsg.id;
    if (!id)
        return;
    if (!orderRecords[id]) {
        //error while creating order (there were no order update messages)
        orderRecords[id] = {
            recStatus: EOrderRecStatus.INVALID,
            createOrderCorrelationId: '',
        };
        if (orderUpdateCallback)
            orderUpdateCallback(orderRecords);
    }
    else {
        const rec = orderRecords[id];
        if (rec.createOrderCorrelationId === errorMsg.correlationId) {
            rec.recStatus = EOrderRecStatus.INVALID;
            return;
        }
        if (rec.recStatus === EOrderRecStatus.INITIALIZING) {
            rec.recStatus = EOrderRecStatus.INVALID;
        }
        // notifications or errors for existing (created orders)
        // do nothing
    }
};
export const getOrderStore = () => orderRecords;
export const clearOrderStore = () => {
    orderRecords = {};
};
function toOrder(orderData) {
    const order = {
        id: orderData.id,
        tenant: orderData.tenant,
        orderType: orderData.orderType,
        created: orderData.created,
        status: orderData.status,
        buckets: [],
        closed: orderData.closed,
    };
    return order;
}
